@@ -557,10 +557,6 @@ __imlib_CleanupImagePixmapCache(void)
 }
 #endif
 
-#define LOADERS_UNINITIALISED -4444
-
-static int          errors = LOADERS_UNINITIALISED;
-
 /* try dlopen()ing the file if we succeed finish filling out the malloced */
 /* loader struct and return it */
 ImlibLoader        *
@@ -663,7 +659,11 @@ __imlib_TrimLoaderList(char **list, int *num)
         if (!list[i])
            continue;
         ext = strrchr(list[i], '.');
-        if ((ext) && (!strcasecmp(ext, ".so")))
+        if ((ext) && (
+#ifdef __CYGWIN__
+            (!strcasecmp(ext, ".dll")) ||
+#endif
+            (!strcasecmp(ext, ".so"))))
           {
              /* Don't add the same loader multiple times... */
              if (!__imlib_ItemInList(ret, size, list[i]))
